<?php
/*
Plugin Name: Affied Ads Suite
Description: Monetize your Wordpress with Affied.com using automatic integration or a shortcode that displays sponsored ads.
Version: 1.10
Author: Nadir Patel, Affied
Author URI: https://affied.com
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: affied-ads-suite
Domain Path: /languages
*/

/*
This is a complete WordPress plugin that allows users to monetize their Wordpress site. Featuring built-in account registration and ad statistics with sponsored ads from Affied <www.affied.com>

Plugin Features:
 + Setup screen that allows admin to signup and connect their site to Affied.com
 + Settings page where admin can view/modify their Affied Publisher ID, API Key, Widget Code, and choose where they want ads to display automatically.
 + Statistics page that displays the user's ad impressions, clicks, and revenue which is retrieved from Affied Statistics API.
 + Shortcode that admin can use to display ads in their posts and pages using [affied_widget]
 + Gutenberg block that admin can use to insert the shortcode into their posts and pages using the block editor.
*/

include_once(plugin_dir_path(__FILE__) . 'affied-widget.php');

class Affied
{

    public function __construct()
    {

        // Add custom CSS for the menu icon
        add_action('admin_head', array($this, 'add_custom_admin_css'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_styling'));

        // Check requirements
        if (!$this->check_requirements()) {
            add_action('admin_notices', array($this, 'show_requirements_error'));
            return;
        }

        // Register the Affied block
        add_action('init', array($this, 'register_affied_block'));

        // Enqueue the Affied block script
        add_action('enqueue_block_editor_assets', array($this, 'enqueue_affied_block_script'));

        // Register a REST API endpoint that returns the affied_widget_code
        add_action('rest_api_init', array($this, 'register_rest_route'));

        // Create the statistics table
        register_activation_hook(__FILE__, array($this, 'create_statistics_table'));

        // Register the uninstall function
        register_uninstall_hook(__FILE__, array('Affied', 'uninstall'));

        // Load text domain
        load_plugin_textdomain('affied', false, basename(dirname(__FILE__)) . '/languages');

        // Add the settings page
        add_action('admin_menu', array($this, 'create_plugin_settings_page'));

        // Register the settings
        add_action('admin_init', array($this, 'setup_sections_and_fields'));

        // Register the shortcode
        add_shortcode('affied', array($this, 'handle_shortcode'));

        // Redirect to the setup screen when the plugin is activated
        register_activation_hook(__FILE__, array($this, 'redirect_to_setup_screen'));

        // For auto-injecting ads into certain areas
        add_filter('the_content', array($this, 'inject_into_posts'));
        add_action('wp_head', array($this, 'inject_into_pages'));
        add_action('get_sidebar', array($this, 'inject_into_sidebar'));

        $page_placement = get_option('affied_page_placement', 'below_header');
        if (get_option('affied_inject_pages') == '1') {
            if ($page_placement == 'below_header') {
                add_action('wp_head', array($this, 'inject_widget_into_pages'));
            } else {
                add_action('wp_footer', array($this, 'inject_widget_into_pages'));
            }
        }
    }

    private function check_requirements()
    {
        global $wp_version;
        if (version_compare(PHP_VERSION, '7.0', '<') || version_compare($wp_version, '5.0', '<')) {
            return false;
        }
        return true;
    }

    public function show_requirements_error()
    {
        echo '<div class="error"><p>' . __('Affied Plugin requires PHP 7.0 and WordPress 5.0 or higher!', 'affied') . '</p></div>';
    }

    public static function uninstall()
    {
        // Fetch the plugin setting that determines if data should be deleted on uninstall
        $delete_data = get_option('affied_delete_data_on_uninstall');

        // If the setting is enabled, proceed with data cleanup
        if ($delete_data) {
            // Remove the associated options from the database
            delete_option('affied_publisher_id');
            delete_option('affied_api_key');
            delete_option('affied_widget_code');
            delete_option('affied_delete_data_on_uninstall');
        }
    }

    public function add_custom_admin_css()
    {
        echo '<style>
            #adminmenu .toplevel_page_affied div.wp-menu-image img {
                filter: none;
            }
        </style>';
    }

    public function enqueue_styling()
    {
        // Enqueue Bootstrap CSS
        wp_enqueue_style('bootstrap-css', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css');

        // Enqueue Bootstrap JS and Popper.js
        wp_enqueue_script('popper-js', plugin_dir_url(__FILE__) . 'js/popper.min.js', array('jquery'), '', true);
        wp_enqueue_script('bootstrap-js', plugin_dir_url(__FILE__) . 'js/bootstrap.min.js', array('jquery', 'popper-js'), '', true);

        //  Enqueue our local styling
        wp_enqueue_style('affied-local-css', plugin_dir_url(__FILE__) . 'css/style.css');
        wp_enqueue_style('affied-datepicker-css', plugin_dir_url(__FILE__) . 'css/datepicker.min.css');

        wp_enqueue_script('affied-datepicker-js', plugin_dir_url(__FILE__) . 'js/datepicker.min.js', array('jquery'), null, true);
    }


    public function affied_navbar()
    {
?>
        <nav class="navbar navbar-expand-lg navbar-light bg-light rounded mb-4">
            <a class="navbar-brand" href="https://affied.com" target="_blank">
                <img src="//affied.com/theme/modern/assets/images/logo-light.png" height="22" class="d-inline-block align-top" alt="Affied">
            </a>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="<?php echo admin_url('admin.php?page=affied-dashboard'); ?>">Dashboard</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="<?php echo admin_url('admin.php?page=affied-settings'); ?>">Settings</a>
                    </li>
                </ul>
            </div>
        </nav>
    <?php
    }


    public function register_affied_block()
    {
        if (function_exists('register_block_type')) {
            register_block_type('affied/shortcode', array(
                'editor_script' => 'affied-block-script',
                'render_callback' => array($this, 'render_affied_block'),
                'icon' => 'https://affied.com/theme/affied/assets/affied-wp-icon.png',
            ));
        }
    }


    public function render_affied_block($attributes)
    {
        return do_shortcode('[affied]');
    }

    public function enqueue_affied_block_script()
    {
        wp_enqueue_script('affied-block-script', plugin_dir_url(__FILE__) . 'js/block.js', array('wp-blocks', 'wp-element', 'wp-editor'), '1.0', true);
    }


    /* Statistics page */

    public function create_statistics_table()
    {
        global $wpdb;
        $table_name = $wpdb->prefix . 'affied_statistics';
        $charset_collate = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE $table_name (
            date date NOT NULL,
            impressions bigint(20) NOT NULL,
            clicks bigint(20) NOT NULL,
            revenue decimal(10,2) NOT NULL,
            PRIMARY KEY  (date)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }

    public function statistics_page_content()
    {
        $this->affied_navbar();

        // Check if the setup_completed query parameter is set and display the success message
        if (isset($_GET['setup_completed']) && $_GET['setup_completed'] == '1') {
            echo '<div class="alert alert-success" role="alert"><h3>';
            _e('Setup has been completed and this site is connected to Affied Successfully', 'affied');
            echo '</h3></div>';
        }

        // Get the publisher ID and API key from the database
        $publisher_id = get_option('affied_publisher_id');
        $api_key = get_option('affied_api_key');

        // Set the default start and end dates
        $start_date = isset($_POST['start_date']) ? sanitize_text_field($_POST['start_date']) : date('Y-m-d');
        $end_date = isset($_POST['end_date']) ? sanitize_text_field($_POST['end_date']) : date('Y-m-d');

        // Send a GET request to the Affied API
        $response = wp_remote_get("https://www.affied.com/api/publisher_reports?user_id=$publisher_id&publisher_api_key=$api_key&start=$start_date&end=$end_date&type=daily");

        // Check for errors
        if (is_wp_error($response)) {
            echo '<div class="error"><p>' . __('An error occurred while fetching the statistics.', 'affied') . '</p></div>';
            return;
        }

        // Decode the JSON response
        $data = json_decode(wp_remote_retrieve_body($response), true);


        // Check for errors
        if (isset($data['error'])) {
            echo '<div class="error"><p>' . esc_html($data['error']) . '</p></div>';
            return;
        }

        echo '<h1>Dashboard</h1>';
        echo '<p>&nbsp;</p><form method="post">';
        echo '<p><label for="start_date">Start Date: </label><input type="text" id="start_date" name="start_date" value="' . esc_attr($start_date) . '"></p>';
        echo '<p><label for="end_date">End Date: </label><input type="text" id="end_date" name="end_date" value="' . esc_attr($end_date) . '"></p>';
        echo '<p><input type="submit" value="Update"></p>';
        echo '</form>';
        echo '<p>Statistics from <h3>' . esc_attr($start_date) . ' to ' . esc_attr($end_date) . '</h3></p>';

        // Display the statistics in a table
        echo '<table class="wp-list-table widefat fixed striped">';
        echo '<thead>
                <tr>
                    <th>Date</th>
                    <th>Site</th>
                    <th>Impressions</th>
                    <th>Clicks</th>
                    <th>Revenue</th>
                </tr>
            </thead>';
        echo '<tbody>';
        foreach ($data['reports'] as $report) {
            if ($report['impressions'] == null) {
                $report['impressions'] = 0;
            }
            if ($report['clicks'] == null) {
                $report['clicks'] = 0;
            }
            if ($report['revenue'] == null) {
                $report['revenue'] = 0.00;
            }

            echo '<tr>';
            echo '<td>' . esc_html($report['name']) . '</td>';
            echo '<td>' . esc_html($report['impressions']) ?? 0 . '</td>';
            echo '<td>' . esc_html($report['clicks']) ?? 0 . '</td>';
            echo '<td>$' . esc_html($report['revenue']) ?? 0.00 . '</td>';
            echo '</tr>';
        }
        echo '</tbody>';
        echo '</table>';
        echo '</div>';
        echo '<p>* The numbers above are estimates only and are subject to further audits. In order to get paid, please ensure your <a href=https://affied.com/login/>payment information</a> is up to date on Affied.</p>';

        // Add the date picker script
        echo '<script>
            jQuery(function() {
                jQuery("#start_date, #end_date").datepicker({
                    dateFormat: "yy-mm-dd"
                });
            });
        </script>';
    }


    public function create_plugin_settings_page()
    {

        // Add the submenu item that links to the setup screen
        add_submenu_page('affied-main', __('First Time Setup', 'affied'), __('First Time Setup', 'affied'), 'manage_options', 'affied-setup', array($this, 'create_setup_screen'));


        // Check if the setup has been completed
        $publisher_id = get_option('affied_publisher_id');
        $api_key = get_option('affied_api_key');
        $widget_code = get_option('affied_widget_code');

        // Define the top-level slug based on whether the setup is completed
        $top_level_slug = $publisher_id && $api_key && $widget_code ? 'affied-dashboard' : 'affied-setup';

        // Create the top-level menu page
        add_menu_page(__('Affied', 'affied'), __('Affied', 'affied'), 'manage_options', $top_level_slug, null, 'https://affied.com/theme/affied/assets/affied-wp-icon.png', 3);

        // If the setup hasn't been completed, add the "Setup" submenu
        if (!$publisher_id || !$api_key || !$widget_code) {
            add_submenu_page('affied-setup', __('First Time Setup', 'affied'), __('First Time Setup', 'affied'), 'manage_options', 'affied-setup', array($this, 'create_setup_screen'));
        } else {
            // Add the submenu item that links to the dashboard (formerly statistics)
            add_submenu_page($top_level_slug, __('Dashboard', 'affied'), __('Dashboard', 'affied'), 'manage_options', 'affied-dashboard', array($this, 'statistics_page_content'));

            // Add the submenu item that links to the settings page
            add_submenu_page($top_level_slug, __('Settings', 'affied'), __('Settings', 'affied'), 'manage_options', 'affied-settings', array($this, 'plugin_settings_page_content'));
        }
    }


    public function plugin_settings_page_content()
    {
        $this->affied_navbar();

        // Check if the setup_completed query parameter is set and display the success message
        if (isset($_GET['setup_completed']) && $_GET['setup_completed'] == '1') {
            echo '<div class="alert alert-success" role="alert"><h3>';
            _e('Setup has been completed and this site is connected to Affied Successfully', 'affied');
            echo '</h3></div>';
        }
    ?>
        <div>
            <form method="post" action="options.php">
                <?php
                settings_fields('affied');
                do_settings_sections('affied');
                submit_button();
                ?>
            </form>
        </div>
        <div class="clear"></div>
        <?php
    }

    /* *************************************** */
    /* Widget injection functions ************ */
    /* *************************************** */

    public function sanitize_script($script)
    {
        $allowed_html = array(
            'div' => array(
                'id' => array(),
            ),
            'script' => array(
                'type' => array(),
                'src' => array(),
                'var' => array(),
                'ref' => array(),
                'url' => array(),
                'wid' => array(),
                'type' => array(),
                'js' => array(),
            ),
        );

        return wp_kses($script, $allowed_html);
    }

    public function handle_shortcode($atts)
    {
        // Get the widget code from the database
        $widget_code = get_option('affied_widget_code');

        if (!$widget_code) {
            return 'Affied widget code will show here when setup has been completed.';
        }

        // Define allowed HTML tags and attributes
        $allowed_html = array(
            'div' => array(
                'id' => array(),
            ),
            'script' => array(
                'type' => array(),
                'src' => array(),
                'var' => array(),
                'ref' => array(),
                'url' => array(),
                'wid' => array(),
                'type' => array(),
                'js' => array(),
            ),
        );

        // Return the widget code with allowed HTML tags
        return wp_kses($widget_code, $allowed_html);
    }


    public function inject_sidebar_widgets($sidebars_widgets)
    {

        if (get_option('affied_inject_sidebar')) {
            if (isset($sidebars_widgets['sidebar-1'])) {
                array_unshift($sidebars_widgets['sidebar-1'], 'affied_widget');
            }
        }

        return $sidebars_widgets;
    }

    public function inject_page_content($content)
    {
        $widget_code = get_option('affied_widget_code');
        $placement = get_option('affied_page_placement');

        if (is_page() && get_option('affied_inject_pages')) {
            if ($placement == 'below_header') {
                $content = $widget_code . $content;
            } elseif ($placement == 'above_footer') {
                $content .= $widget_code;
            }
        }

        return $content;
    }

    public function inject_content($content)
    {
        $widget_code = get_option('affied_widget_code');

        if (is_single() && get_option('affied_inject_posts')) {
            $content .= $widget_code;
        }

        return $content;
    }


    public function inject_into_posts($content)
    {
        if (get_option('affied_inject_posts') && is_single()) {
            $content .= $this->get_widget_code();
        }
        return $content;
    }

    public function inject_widget_into_pages($content)
    {
        if (is_page() && get_option('affied_inject_pages')) {
            $placement = get_option('affied_page_placement');
            if ($placement == 'below_header') {
                add_action('wp_header', array($this, 'output_widget_code'));
            } elseif ($placement == 'above_footer') {
                add_action('wp_footer', array($this, 'output_widget_code'));
            }
        }
        return $content;
    }

    public function output_widget_code()
    {
        echo $this->handle_shortcode([]);
    }

    public function inject_into_pages()
    {
        if (get_option('affied_inject_pages') && is_page()) {
            echo $this->get_widget_code();
        }
    }

    public function inject_into_sidebar()
    {
        if (get_option('affied_inject_sidebar')) {
            echo $this->get_widget_code();
        }
    }

    // register the the rest route for getting widget code
    public function register_rest_route()
    {
        register_rest_route('affied/v1', '/get-widget-code', array(
            'methods' => 'GET',
            'callback' => array($this, 'get_widget_code'),
            'permission_callback' => '__return_true'  // This line ensures the endpoint is public
        ));
    }

    public function get_widget_code()
    {
        // Define allowed HTML tags and attributes
        $allowed_html = array(
            'div' => array(
                'id' => array(),
            ),
            'script' => array(
                'type' => array(),
                'src' => array(),
                'var' => array(),
                'ref' => array(),
                'url' => array(),
                'wid' => array(),
                'type' => array(),
                'js' => array(),
            ),
        );

        // Return the widget code with allowed HTML tags
        return wp_kses(get_option('affied_widget_code', 'Affied widget code will show here when setup has been completed.'), $allowed_html);
    }






    /* *************************************************************** */
    /* Setup screen and registration process */
    /* *************************************************************** */

    public function page_placement_callback($arguments)
    {
        $value = get_option('affied_page_placement', 'below_header'); // default to below_header
        $options = array(
            'below_header' => __('Below Header', 'affied'),
            'above_footer' => __('Above Footer', 'affied')
        );

        echo '<select name="affied_page_placement" id="affied_page_placement">';
        foreach ($options as $key => $label) {
            echo '<option value="' . esc_attr($key) . '"' . selected($value, $key, false) . '>' . esc_html($label) . '</option>';
        }
        echo '</select>';
    }

    public function field_callback_checkbox($arguments)
    {
        $value = get_option($arguments['id']);
        echo '<input name="' . $arguments['id'] . '" id="' . $arguments['id'] . '" type="checkbox" value="1" ' . checked(1, $value, false) . ' />';
    }

    public function field_callback_dropdown($arguments)
    {
        $value = get_option($arguments['id']);
        echo '<select name="' . $arguments['id'] . '" id="' . $arguments['id'] . '">';
        echo '<option value="below_header" ' . selected($value, 'below_header', false) . '>Below Page Header</option>';
        echo '<option value="above_footer" ' . selected($value, 'above_footer', false) . '>Above Page Footer</option>';
        echo '</select>';
    }

    public function field_callback($arguments)
    {

        $value = get_option($arguments['id']);
        $sanitized_value = $arguments['id'] === 'affied_widget_code' ? $this->sanitize_script($value) : sanitize_text_field($value);

        if ($arguments['id'] === 'affied_widget_code') {
            echo '<textarea name="' . $arguments['id'] . '" id="' . $arguments['id'] . '" rows=\"40\" cols=\"3\">' . esc_textarea($sanitized_value) . '</textarea>';
        } else {
            echo '<input name="' . $arguments['id'] . '" id="' . $arguments['id'] . '" type="text" value="' . esc_attr($sanitized_value) . '" />';
        }
    }

    public function setup_sections_and_fields()
    {
        // uninstall all data from database if box is checked
        add_settings_field('affied_delete_data_on_uninstall', __('Delete data on uninstall', 'affied'), array($this, 'field_callback_checkbox'), 'affied', 'affied_section', array('id' => 'affied_delete_data_on_uninstall'));
        register_setting('affied', 'affied_delete_data_on_uninstall');

        // show the settings panel
        add_settings_section('affied_section', __('Widget Settings', 'affied'), array(), 'affied');

        // lets grab the data after setup
        add_settings_field('affied_publisher_id', __('Publisher ID', 'affied'), array($this, 'field_callback'), 'affied', 'affied_section', array('id' => 'affied_publisher_id'));
        register_setting('affied', 'affied_publisher_id');

        add_settings_field('affied_api_key', __('API Key', 'affied'), array($this, 'field_callback'), 'affied', 'affied_section', array('id' => 'affied_api_key'));
        register_setting('affied', 'affied_api_key');

        add_settings_field('affied_widget_code', __('Widget Code', 'affied'), array($this, 'field_callback'), 'affied', 'affied_section', array('id' => 'affied_widget_code'));
        register_setting('affied', 'affied_widget_code');



        // Additional settings fields for native ad units
        // Allow user to add/remove ads where needed
        // Ads will only show once either in sidebar, posts, or pages
        add_settings_field('affied_inject_posts', __('Inject Native Ads in Posts', 'affied'), array($this, 'field_callback_checkbox'), 'affied', 'affied_section', array('id' => 'affied_inject_posts'));
        register_setting('affied', 'affied_inject_posts');

        add_settings_field('affied_inject_pages', __('Inject Native Ads in Pages', 'affied'), array($this, 'field_callback_checkbox'), 'affied', 'affied_section', array('id' => 'affied_inject_pages'));
        register_setting('affied', 'affied_inject_pages');

        add_settings_field('affied_page_placement', __('Native Ads Page Placement', 'affied'), array($this, 'field_callback_dropdown'), 'affied', 'affied_section', array('id' => 'affied_page_placement'));
        register_setting('affied', 'affied_page_placement');

        add_settings_field('affied_inject_sidebar', __('Inject Native Ads in Sidebar', 'affied'), array($this, 'field_callback_checkbox'), 'affied', 'affied_section', array('id' => 'affied_inject_sidebar'));
        register_setting('affied', 'affied_inject_sidebar');
    }

    // intially go to setup screen after plugin activated
    public function redirect_to_setup_screen()
    {
        add_option('affied_do_activation_redirect', true);
    }


    // setup screen and save response
    public function create_setup_screen()
    {
        $this->affied_navbar();

        // Get current user
        $current_user = wp_get_current_user();

        // Check if the site is already registered
        $publisher_id = get_option('affied_publisher_id');
        $api_key = get_option('affied_api_key');
        $widget_code = get_option('affied_widget_code');

        if ($publisher_id && $api_key && $widget_code) {
            // The site is already registered, display the success message
            echo '<div class="alert alert-success" role="alert">';
            _e('Setup has been completed and this site is connected to Affied Successfully', 'affied');
            echo '</div>';
        } else {

            if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['affied_setup_nonce']) && wp_verify_nonce($_POST['affied_setup_nonce'], 'affied_setup')) {
                $this->register_site_with_affied_api();
            }

            settings_errors('affied_setup');
        ?>
            <div class="wrap">
                <h2><?php _e('First Time Setup', 'affied'); ?></h2>
                <p class="text-small">Only one account is allowed per individual/company, but you can have multiple sites under one account. If you need to add additional sites under your account, please <a href="mailto:support@affied.com">contact us</a></p>
                <form method="post" action="<?php echo esc_url(admin_url('admin.php?page=affied-setup')); ?>">
                    <?php wp_nonce_field('affied_setup', 'affied_setup_nonce'); ?>
                    <table class="form-table">
                        <tr>
                            <th scope="row">
                                <label for="site_name"><?php _e('Site Name', 'affied'); ?></label>
                            </th>
                            <td><input type="text" name="site_name" id="site_name" value="<?php echo esc_attr(get_bloginfo('name')); ?>" class="regular-text" required></td>
                        <tr>
                            <th scope="row">
                                <label for="site_url"><?php _e('Site URL', 'affied'); ?></label>
                            </th>
                            <td>
                                <input type="url" name="site_url" id="site_url" value="<?php echo esc_url(get_site_url()); ?>" class="regular-text" required>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="name"><?php _e('Your Full Name', 'affied'); ?></label></th>
                            <td><input type="text" name="name" id="name" value="<?php echo esc_attr($current_user->display_name); ?>" class="regular-text" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="email"><?php _e('Your Email Address', 'affied'); ?></label></th>
                            <td><input type="email" name="email" id="email" value="<?php echo esc_attr($current_user->user_email); ?>" class="regular-text" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="password"><?php _e('Password', 'affied'); ?></label></th>
                            <td><input type="password" name="password" id="password" class="regular-text" required></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="password_confirm"><?php _e('Confirm Password', 'affied'); ?></label></th>
                            <td><input type="password" name="password_confirm" id="password_confirm" class="regular-text" required></td>
                        </tr>
                        <tr>
                            <th scope="row" colspan="2">
                                <input type="checkbox" name="terms" id="terms"> I agree to <a href="https://affied.com/terms">Terms and Conditions</a>
                            </th>
                        </tr>
                        <tr class="submit">
                            <th class="row" colspan="2">
                                <input type="submit" name="submit" id="submit" class="button button-primary" value="<?php _e('Complete Setup', 'affied'); ?>">
                            </th>
                        </tr>
                        </p>
                    </table>
                </form>
            </div>
<?php
        }
    }


    public function register_site_with_affied_api()
    {
        if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['affied_setup_nonce']) && wp_verify_nonce($_POST['affied_setup_nonce'], 'affied_setup')) {


            $response = wp_remote_get('https://affied.com/api/wordpress/register', array(
                'body' => array(
                    'name' => sanitize_text_field($_POST['name']),
                    'email' => sanitize_email($_POST['email']),
                    'password' => sanitize_text_field($_POST['password']),
                    'site_name' => sanitize_text_field($_POST['site_name']),
                    'site_url' => sanitize_text_field($_POST['site_url']),
                ),
            ));

            // Debug code
            $debug_info = print_r($response, true);
            file_put_contents(plugin_dir_path(__FILE__) . 'debug.txt', $debug_info);

            // Error handling
            if (is_wp_error($response)) {
                $error_message = $response->get_error_message();
                echo "Something went wrong: $error_message";
            } else {
                $body = wp_remote_retrieve_body($response);
                $data = json_decode($body, true);


                // Save the received parameters to the database
                update_option('affied_publisher_id', sanitize_text_field($data['publisher_id']));
                update_option('affied_publisher_name', sanitize_text_field($data['publisher_name']));
                update_option('affied_publisher_login', sanitize_text_field($data['publisher_login']));
                update_option('affied_publisher_password', sanitize_text_field($data['publisher_password']));
                update_option('affied_site_id', sanitize_text_field($data['site_id']));
                update_option('affied_site_name', sanitize_text_field($data['site_name']));
                update_option('affied_site_url', sanitize_text_field($data['site_url']));
                update_option('affied_api_key', sanitize_text_field($data['api_key']));
                update_option('affied_widget_id', sanitize_text_field($data['wid']));

                // Sanitize the widget code with wp_kses
                $allowed_html = array(
                    'div' => array(
                        'id' => array(),
                    ),
                    'script' => array(
                        'type' => array(),
                        'src' => array(),
                        'var' => array(),
                        'ref' => array(),
                        'url' => array(),
                    ),
                );
                $sanitized_widget_code = wp_kses($data['widget_code'], $allowed_html);
                update_option('affied_widget_code', $sanitized_widget_code);

                add_settings_error('affied_setup', 'affied_setup_success', __('This site is now successfully registered with Affied. You can now <a href=admin.php?page=affied-settings>configure the settings</a> and choose where to display ads', 'affied'), 'updated');

                // Redirect to the Settings page to display the success message
                wp_redirect(admin_url('admin.php?page=affied-settings&setup_completed=1'));
                // exit;
            }
        }
    }
}


new Affied();
